@@ -1,4 +1,4 @@
-# $Id: Cart.pm 478 2005-03-22 00:50:54Z claco $
+# $Id: Cart.pm 648 2005-08-05 00:44:06Z claco $
 package AxKit::XSP::Handel::Cart;
 use strict;
 use warnings;
@@ -55,7 +55,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Cart';
     sub parse_start {
         my ($e, $tag, %attr) = @_;
 
-        AxKit::Debug(5, "[Handel] parse_start [$tag] context: " . join('->', @context));
+        AxKit::Debug(5, "[Handel] [Cart] parse_start [$tag] context: " . join('->', @context));
 
         if (exists $attr{'type'}) {
             if ($attr{'type'} =~ /^[A-Z]{1}/) {
@@ -250,10 +250,10 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Cart';
                     my $from   = $attr{'from'}    || $cfg->{'HandelCurrencyCode'};
                     my $to     = $attr{'to'}      || $attr{'code'} || $cfg->{'HandelCurrencyCode'};
 
-                    AxKit::Debug(5, "[Handel] [$tag] code=$code, format=$format, from=$from, to=$to");
+                    AxKit::Debug(5, "[Handel] [Cart] [$tag] code=$code, format=$format, from=$from, to=$to");
 
                     if ($attr{'convert'}) {
-                        $e->append_to_script("\$_xsp_handel_cart_cart->$tag->convert('$from', '$to', '".$attr{'format'}."', '$format');\n");
+                        $e->append_to_script("\$_xsp_handel_cart_cart->$tag->convert('$from', '$to', '".($attr{'format'}||'')."', '$format');\n");
                     } elsif ($attr{'format'}) {
                         $e->append_to_script("\$_xsp_handel_cart_cart->$tag->format('$code', '$format');\n");
                     };
@@ -302,10 +302,10 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Cart';
                     my $from   = $attr{'from'}    || $cfg->{'HandelCurrencyCode'};
                     my $to     = $attr{'to'}      || $attr{'code'} || $cfg->{'HandelCurrencyCode'};
 
-                    AxKit::Debug(5, "[Handel] [$tag] code=$code, format=$format, from=$from, to=$to");
+                    AxKit::Debug(5, "[Handel] [Cart] [$tag] code=$code, format=$format, from=$from, to=$to");
 
                     if ($attr{'convert'}) {
-                        $e->append_to_script("\$_xsp_handel_cart_item->$tag->convert('$from', '$to', '".$attr{'format'}."', '$format');\n");
+                        $e->append_to_script("\$_xsp_handel_cart_item->$tag->convert('$from', '$to', '".($attr{'format'}||'')."', '$format');\n");
                     } elsif ($attr{'format'}) {
                         $e->append_to_script("\$_xsp_handel_cart_item->$tag->format('$code', '$format');\n");
                     };
@@ -486,7 +486,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Cart';
     sub parse_end {
         my ($e, $tag) = @_;
 
-        AxKit::Debug(5, "[Handel] parse_end   [$tag] context: " . join('->', @context));
+        AxKit::Debug(5, "[Handel] [Cart] parse_end   [$tag] context: " . join('->', @context));
 
         ## cart:new
         if ($tag eq 'new') {
@@ -1205,7 +1205,7 @@ Loops through all items in the current cart:
                         <item>
                             <sku><cart:sku/></sku>
                             <description><cart:description/></cart:description>
-                            <sku><cart:sku/></sku>
+                            <name><cart:name/></name>
                             <quantity><cart:quantity/></quantity>
                             <price><cart:price/></price>
                             <total><cart:total/></total>
@@ -1507,6 +1507,10 @@ Saves the current cart by setting its type to C<CART_TYPE_SAVED>:
         </cart:no-results>
     </cart:cart>
 
+=head2 <cart:shopper>
+
+Context aware tag that gets or sets the shopper id for the current cart.
+
 =head2 <cart:sku>
 
 Context aware tag to get or set the sku of a cart item.
