@@ -1,9 +1,9 @@
-# $Id: WriteToStash.pm 1336 2006-07-15 03:54:43Z claco $
+# $Id: WriteToStash.pm 709 2005-08-11 01:25:20Z claco $
 package Handel::TestPipeline::WriteToStash;
 use strict;
 use warnings;
 use base 'Handel::Checkout::Plugin';
-use Handel::Constants qw(:checkout);
+use Handel::Constants qw(:checkout :returnas);
 
 sub register {
     my ($self, $ctx) = @_;
@@ -19,4 +19,4 @@ sub handler {
     return CHECKOUT_HANDLER_OK;
 };
 
-1;
+1;
\ No newline at end of file
